@@ -1,7 +1,7 @@
 """Example macro."""
 
 revision = "$Rev: 6326 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/branches/0.11-stable/sample-plugins/HelloWorld.py $"
+url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-0.11.6/sample-plugins/HelloWorld.py $"
 
 #
 # The following shows the code for macro, old-style.
