@@ -4,8 +4,8 @@ from trac.web.api import ITemplateStreamFilter
 from genshi.builder import tag
 from genshi.filters import Transformer
 
-revision = "$Rev: 6326 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/branches/0.11-stable/sample-plugins/ticket_clone.py $"
+revision = "$Rev: 8087 $"
+url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-0.11.6/sample-plugins/ticket_clone.py $"
 
 class SimpleTicketCloneButton(Component):
     """Add a 'Clone' button to the ticket box. 
@@ -43,8 +43,9 @@ class SimpleTicketCloneButton(Component):
             tag.div(
                 tag.input(type="submit", name="clone", value="Clone",
                     title="Create a copy of this ticket"),
-                [tag.input(type="hidden", name=n, value=v) for n, v in
+                [tag.input(type="hidden", name='field_'+n, value=v) for n, v in
                     fields.items()],
+                tag.input(type="hidden", name='preview', value=''),
                 class_="inlinebuttons"),
-            method="get", action=req.href.newticket())
+            method="post", action=req.href.newticket())
 
