@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2003-2008 Edgewall Software
+# Copyright (C) 2003-2009 Edgewall Software
 # Copyright (C) 2003-2005 Jonas Borgström <jonas@edgewall.com>
 # All rights reserved.
 #
@@ -154,10 +154,15 @@ class TicketSystem(Component):
             (''since 0.11'').""")
 
     restrict_owner = BoolOption('ticket', 'restrict_owner', 'false',
-        """Make the owner field of tickets use a drop-down menu. See
+        """Make the owner field of tickets use a drop-down menu.
+        Be sure to understand the performance implications before activating
+        this option. See
         [TracTickets#Assign-toasDrop-DownList Assign-to as Drop-Down List]
         (''since 0.9'').""")
 
+    _fields = None
+    _custom_fields = None
+
     def __init__(self):
         self.log.debug('action controllers for ticket workflow: %r' % 
                 [c.__class__.__name__ for c in self.action_controllers])
@@ -195,7 +200,8 @@ class TicketSystem(Component):
         if self._fields is None:
             self._fields_lock.acquire()
             try:
-                self._fields = self._get_ticket_fields()
+                if self._fields is None: # double-check (race after 1st check)
+                    self._fields = self._get_ticket_fields()
             finally:
                 self._fields_lock.release()
         return [f.copy() for f in self._fields]
@@ -208,7 +214,6 @@ class TicketSystem(Component):
         finally:
             self._fields_lock.release()
 
-    _fields = None
     def _get_ticket_fields(self):
         from trac.ticket import model
 
@@ -265,6 +270,10 @@ class TicketSystem(Component):
                 self.log.warning('Duplicate field name "%s" (ignoring)',
                                  field['name'])
                 continue
+            if field['name'] in self.reserved_field_names:
+                self.log.warning('Field name "%s" is a reserved name '
+                                 '(ignoring)', field['name'])
+                continue
             if not re.match('^[a-zA-Z][a-zA-Z0-9_]+$', field['name']):
                 self.log.warning('Invalid name for custom field: "%s" '
                                  '(ignoring)', field['name'])
@@ -274,16 +283,20 @@ class TicketSystem(Component):
 
         return fields
 
+    reserved_field_names = ['report', 'order', 'desc', 'group', 'groupdesc',
+                            'col', 'row', 'format', 'max', 'page', 'verbose',
+                            'comment']
+
     def get_custom_fields(self):
         if self._custom_fields is None:
             self._fields_lock.acquire()
             try:
-                self._custom_fields = self._get_custom_fields()
+                if self._custom_fields is None: # double-check
+                    self._custom_fields = self._get_custom_fields()
             finally:
                 self._fields_lock.release()
         return [f.copy() for f in self._custom_fields]
 
-    _custom_fields = None
     def _get_custom_fields(self):
         fields = []
         config = self.config['ticket-custom']
@@ -301,7 +314,10 @@ class TicketSystem(Component):
                 if '' in field['options']:
                     field['optional'] = True
                     field['options'].remove('')
+            elif field['type'] == 'text':
+                field['format'] = config.get(name + '.format', 'plain')
             elif field['type'] == 'textarea':
+                field['format'] = config.get(name + '.format', 'plain')
                 field['width'] = config.getint(name + '.cols')
                 field['height'] = config.getint(name + '.rows')
             fields.append(field)
